﻿using Infragistics.Win;
using Infragistics.Win.UltraWinMaskedEdit;
using System.Drawing;
using System.Windows.Forms;

namespace WindowsFormsApplication26
{
    public class MaskedEditDrawFilter : IUIElementDrawFilter
    {
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            //drawParams.DrawString(drawParams.ElementDrawingClipRect, "0", false, false);
            //return true;
            Control control = drawParams.Element.Control;

            Font fontToDispose = drawParams.AppearanceData.CreateFont(control.Font);
            Font fontToDraw = fontToDispose ?? control.Font;
            StringFormat format = (StringFormat)StringFormat.GenericTypographic.Clone();
            format.FormatFlags &= ~StringFormatFlags.FitBlackBox;
            CharacterRange[] ranges = new CharacterRange[1];
            ranges[0] = new CharacterRange(0, 1);
            format.SetMeasurableCharacterRanges(ranges);            
            format.FormatFlags &= ~StringFormatFlags.LineLimit;
            format.FormatFlags &= ~StringFormatFlags.NoWrap;
            format.FormatFlags = StringFormatFlags.NoClip;

            RectangleF rectInsideBorders = drawParams.ElementDrawingRectInsideBorders;
            
            try
            {
                format.FormatFlags |= StringFormatFlags.NoClip;

                DrawUtility.DrawString(
                    drawParams.Graphics, 
                    "0", 
                    fontToDraw, 
                    (SolidBrush)drawParams.TextBrush,
                    rectInsideBorders, 
                    format, 
                    GdiDrawStringFlags.GDIPlus);

                format.FormatFlags &= ~StringFormatFlags.NoClip;

                DrawUtility.DrawString(
                    drawParams.Graphics,
                    "0",
                    fontToDraw,
                    (SolidBrush)drawParams.TextBrush,
                    rectInsideBorders,
                    format,
                    GdiDrawStringFlags.GDIPlus);
            }
            finally
            {
                if (null != fontToDispose)
                    fontToDispose.Dispose();
            }

          return true;
        }



        /// <summary>
        /// 
        /// </summary>
        /// <param name="drawParams"></param>
        /// <returns></returns>
        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            var displayCharUIElement = drawParams.Element as DisplayCharUIElement;
            if (null != displayCharUIElement)
            {
                if (displayCharUIElement.DisplayChar.Char == Form1.replacementChar)
                {
                    return DrawPhase.BeforeDrawForeground;
                }
            }            

            return DrawPhase.None;
        }
    }
}
